.. Libervia (Salut à Toi) documentation master file, created by
   sphinx-quickstart on Thu Jan 24 15:20:15 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Libervia Web documentation
==========================

Welcome to Libervia's documentation. You'll find here both end-user end developer documentations.

Libervia is the web frontend of Salut à Toi (or SàT), a Libre communication ecosystem based on XMPP standard.

With Libervia you have access to main SàT features thanks to its easy to use pages.
It is a highly customizable project, the interface can be modified from slight to major changes, so it can be adapted to your association, university, entreprise or community.

Libervia includes its own web framework, using a unique architecture taking profit of the XMPP standard.

You can follow this documentation to learn more on it, or join our official XMPP room at `sat@chat.jabberfr.org <xmpp:sat@chat.jabberfr.org?join>`_ (also available via a `web link <https://chat.jabberfr.org/converse.js/sat@chat.jabberfr.org>`_)

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation.rst
   web_framework/quick_start.rst
   web_framework/css_framework.rst



Indices and tables
==================

* :ref:`genindex`

..
   * :ref:`modindex`

* :ref:`search`
